@@ -19,9 +19,9 @@
  * -----------------------------------------------------------------*/
 
 /* Define SUNDIALS version numbers */
-#define SUNDIALS_VERSION "5.3.0"
+#define SUNDIALS_VERSION "5.4.0"
 #define SUNDIALS_VERSION_MAJOR 5
-#define SUNDIALS_VERSION_MINOR 3
+#define SUNDIALS_VERSION_MINOR 4
 #define SUNDIALS_VERSION_PATCH 0
 #define SUNDIALS_VERSION_LABEL ""
 
@@ -151,3 +151,23 @@
 /* Mark SUNDIALS API functions for deprecation.
  */
 #define SUNDIALS_DEPRECATED SUNDIALS_EXPORT
+
+/* Mark SUNDIALS function as inline.
+ */
+#ifndef SUNDIALS_CXX_INLINE
+#define SUNDIALS_CXX_INLINE inline
+#endif
+
+#ifndef SUNDIALS_C_INLINE
+#define SUNDIALS_C_INLINE inline
+#endif
+
+#ifdef __cplusplus
+#define SUNDIALS_INLINE SUNDIALS_CXX_INLINE
+#else
+#define SUNDIALS_INLINE SUNDIALS_C_INLINE
+#endif
+
+/* Mark SUNDIALS function as static inline.
+ */
+#define SUNDIALS_STATIC_INLINE static SUNDIALS_INLINE
